Index: main/waeup.kofa/trunk/src/waeup/kofa/students/authentication.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/authentication.py	(revision 7811)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/authentication.py	(revision 7819)
@@ -29,5 +29,5 @@
 from zope.session.interfaces import ISession
 from waeup.kofa.authentication import (
-    KOFAPrincipalInfo, get_principal_role_manager)
+    KofaPrincipalInfo, get_principal_role_manager)
 from waeup.kofa.interfaces import (
     IAuthPluginUtility, IUserAccount, IPasswordValidator)
@@ -135,5 +135,5 @@
         if not account.checkPassword(credentials['password']):
             return None
-        return KOFAPrincipalInfo(id=account.name,
+        return KofaPrincipalInfo(id=account.name,
                              title=account.title,
                              description=account.description,
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/interfaces.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/interfaces.py	(revision 7811)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/interfaces.py	(revision 7819)
@@ -22,5 +22,5 @@
 from zc.sourcefactory.contextual import BasicContextualSourceFactory
 from waeup.kofa.interfaces import (
-    IKOFAObject, academic_sessions_vocab, validate_email, IKOFAUtils)
+    IKofaObject, academic_sessions_vocab, validate_email, IKofaUtils)
 from waeup.kofa.interfaces import MessageFactory as _
 from waeup.kofa.schema import TextLineChoice
@@ -78,5 +78,5 @@
         """
 
-class IStudentsContainer(IKOFAObject):
+class IStudentsContainer(IKofaObject):
     """A students container contains university students.
 
@@ -117,5 +117,5 @@
         """
 
-class IStudentNavigation(IKOFAObject):
+class IStudentNavigation(IKofaObject):
     """Interface needed for student navigation.
 
@@ -126,5 +126,5 @@
         """
 
-class IStudentBase(IKOFAObject):
+class IStudentBase(IKofaObject):
     """Representation of student base data.
 
@@ -206,5 +206,5 @@
         )
 
-class IStudentClearance(IKOFAObject):
+class IStudentClearance(IKofaObject):
     """Representation of student clearance data.
 
@@ -234,5 +234,5 @@
         )
 
-class IStudentPersonal(IKOFAObject):
+class IStudentPersonal(IKofaObject):
     """Representation of student personal data.
 
@@ -268,5 +268,5 @@
         )
 
-class IStudentStudyCourse(IKOFAObject):
+class IStudentStudyCourse(IKofaObject):
     """A container for student study levels.
 
@@ -326,5 +326,5 @@
         )
 
-class IStudentStudyLevel(IKOFAObject):
+class IStudentStudyLevel(IKofaObject):
     """A container for course tickets.
 
@@ -348,5 +348,5 @@
         )
 
-class ICourseTicket(IKOFAObject):
+class ICourseTicket(IKofaObject):
     """A course ticket.
 
@@ -406,10 +406,10 @@
         )
 
-class IStudentAccommodation(IKOFAObject):
+class IStudentAccommodation(IKofaObject):
     """A container for student accommodation objects.
 
     """
 
-class IBedTicket(IKOFAObject):
+class IBedTicket(IKofaObject):
     """A ticket for accommodation booking.
 
@@ -475,5 +475,5 @@
     'p_item'].order
 
-class IStudentChangePassword(IKOFAObject):
+class IStudentChangePassword(IKofaObject):
     """Interface needed for change pasword page.
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/student.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/student.py	(revision 7811)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/student.py	(revision 7819)
@@ -28,6 +28,6 @@
 from waeup.kofa.interfaces import (
     IObjectHistory, IUserAccount, IFileStoreNameChooser, IFileStoreHandler,
-    IKOFAUtils, CLEARANCE, registration_states_vocab)
-from waeup.kofa.image import KOFAImageFile
+    IKofaUtils, CLEARANCE, registration_states_vocab)
+from waeup.kofa.image import KofaImageFile
 from waeup.kofa.imagestorage import DefaultFileStoreHandler
 from waeup.kofa.students.interfaces import IStudent, IStudentNavigation
@@ -63,5 +63,5 @@
     def display_fullname(self):
         middlename = getattr(self, 'middlename', None)
-        kofa_utils = getUtility(IKOFAUtils)
+        kofa_utils = getUtility(IKofaUtils)
         return kofa_utils.fullname(self.firstname, self.lastname, middlename)
 
@@ -284,4 +284,4 @@
             StudentFileStoreHandler, self).createFile(
             store, root,  filename, file_id, file)
-        return file, path, KOFAImageFile(
+        return file, path, KofaImageFile(
             file_obj.filename, file_obj.data)
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/utils.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/utils.py	(revision 7811)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/utils.py	(revision 7819)
@@ -35,5 +35,5 @@
 from zope.component import getUtility
 from zope.formlib.form import setUpEditWidgets
-from waeup.kofa.interfaces import IExtFileStore, IKOFAUtils
+from waeup.kofa.interfaces import IExtFileStore, IKofaUtils
 from waeup.kofa.interfaces import MessageFactory as _
 from waeup.kofa.students.interfaces import IStudentsUtils
@@ -113,5 +113,5 @@
     data_left.append([doc_img])
     #data.append([Spacer(1, 12)])
-    portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+    portal_language = getUtility(IKofaUtils).PORTAL_LANGUAGE
     for widget in studentview.widgets:
         if widget.name == 'form.adm_code':
@@ -164,5 +164,5 @@
       story = []
       frame_footer = Frame(1*cm,0,width-(2*cm),1*cm)
-      portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+      portal_language = getUtility(IKofaUtils).PORTAL_LANGUAGE
       right_text = translate(_('<font size=10>${a} Page ${b} of ${c}</font>',
           mapping = {'a':text, 'b':pdf.getPageNumber(), 'c':number_of_pages}),
@@ -256,5 +256,5 @@
         pdf.setAuthor('%s (%s)' % (view.request.principal.title,
             view.request.principal.id))
-        pdf.setCreator('WAeUP KOFA')
+        pdf.setCreator('WAeUP Kofa')
         width, height = A4
         footer_text = view.label
@@ -275,5 +275,5 @@
         frame_body = Frame(1*cm,1*cm,width-(2*cm),height-(3.5*cm))
         story.append(Paragraph(view.label, style["Heading2"]))
-        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKofaUtils).PORTAL_LANGUAGE
         if student is not None:
             #story.append(Spacer(1, 12))
@@ -288,5 +288,5 @@
         set_up_widgets(view)
         data = []
-        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKofaUtils).PORTAL_LANGUAGE
         for widget in view.widgets:
             f_label = '<font size=12>%s</font>:' % translate(
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/vocabularies.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/vocabularies.py	(revision 7811)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/vocabularies.py	(revision 7819)
@@ -25,5 +25,5 @@
 from zc.sourcefactory.basic import BasicSourceFactory
 from zc.sourcefactory.contextual import BasicContextualSourceFactory
-from waeup.kofa.interfaces import SimpleKOFAVocabulary
+from waeup.kofa.interfaces import SimpleKofaVocabulary
 from waeup.kofa.interfaces import MessageFactory as _
 from waeup.kofa.students.lgas import LGAS
@@ -31,8 +31,8 @@
 from waeup.kofa.university.vocabularies import course_levels
 
-lgas_vocab = SimpleKOFAVocabulary(
+lgas_vocab = SimpleKofaVocabulary(
     *sorted([(x[1],x[0]) for x in LGAS]))
 
-nats_vocab = SimpleKOFAVocabulary(
+nats_vocab = SimpleKofaVocabulary(
     *sorted([(x[1],x[0]) for x in NATS]))
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/workflow.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/workflow.py	(revision 7811)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/workflow.py	(revision 7819)
@@ -6,9 +6,9 @@
 from hurry.workflow.interfaces import IWorkflowState, IWorkflowTransitionEvent
 from waeup.kofa.interfaces import (
-    IObjectHistory, IKOFAWorkflowInfo, IKOFAUtils,
+    IObjectHistory, IKofaWorkflowInfo, IKofaUtils,
     CREATED, ADMITTED, CLEARANCE, REQUESTED, CLEARED, PAID, RETURNING,
     REGISTERED, VALIDATED)
 from waeup.kofa.interfaces import MessageFactory as _
-from waeup.kofa.workflow import KOFAWorkflow, KOFAWorkflowInfo
+from waeup.kofa.workflow import KofaWorkflow, KofaWorkflowInfo
 from waeup.kofa.students.interfaces import IStudent, IStudentsUtils
 
@@ -156,5 +156,5 @@
 UNLOCK_CLEARANCE_TRANS = ('reset3', 'reset4', 'start_clearance')
 
-registration_workflow = KOFAWorkflow(REGISTRATION_TRANSITIONS)
+registration_workflow = KofaWorkflow(REGISTRATION_TRANSITIONS)
 
 class RegistrationWorkflowState(WorkflowState, grok.Adapter):
@@ -167,9 +167,9 @@
     state_id = 'wf.registration.id'
 
-class RegistrationWorkflowInfo(KOFAWorkflowInfo, grok.Adapter):
+class RegistrationWorkflowInfo(KofaWorkflowInfo, grok.Adapter):
     """Adapter to adapt Student objects to workflow info objects.
     """
     grok.context(IStudent)
-    grok.provides(IKOFAWorkflowInfo)
+    grok.provides(IKofaWorkflowInfo)
 
     def __init__(self, context):

Index: main/waeup.kofa/trunk/src/waeup/kofa/students/browser.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/browser.py	(revision 7811)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/browser.py	(revision 7819)
@@ -33,6 +33,6 @@
 from waeup.kofa.accesscodes.workflow import USED
 from waeup.kofa.browser import (
-    KOFAPage, KOFAEditFormPage, KOFAAddFormPage, KOFADisplayFormPage,
-    ContactAdminForm, KOFAForm)
+    KofaPage, KofaEditFormPage, KofaAddFormPage, KofaDisplayFormPage,
+    ContactAdminForm, KofaForm)
 from waeup.kofa.browser.interfaces import ICaptchaManager
 from waeup.kofa.browser.breadcrumbs import Breadcrumb
@@ -40,6 +40,6 @@
 from waeup.kofa.browser.layout import jsaction, action, UtilityView
 from waeup.kofa.interfaces import (
-    IKOFAObject, IUserAccount, IExtFileStore, IPasswordValidator, IContactForm,
-    IKOFAUtils, IUniversity)
+    IKofaObject, IUserAccount, IExtFileStore, IPasswordValidator, IContactForm,
+    IKofaUtils, IUniversity)
 from waeup.kofa.interfaces import MessageFactory as _
 from waeup.kofa.widgets.datewidget import (
@@ -155,5 +155,5 @@
     @property
     def title(self):
-        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKofaUtils).PORTAL_LANGUAGE
         # There is no request attribute, thus we can only translate
         # to the default (portal) language
@@ -161,5 +161,5 @@
             target_language=portal_language)
 
-class StudentsContainerPage(KOFAPage):
+class StudentsContainerPage(KofaPage):
     """The standard view for student containers.
     """
@@ -194,5 +194,5 @@
         return
 
-class StudentsContainerManagePage(KOFAPage):
+class StudentsContainerManagePage(KofaPage):
     """The manage page for student containers.
     """
@@ -245,5 +245,5 @@
         return
 
-class StudentAddFormPage(KOFAAddFormPage):
+class StudentAddFormPage(KofaAddFormPage):
     """Add-form to add a student.
     """
@@ -265,5 +265,5 @@
         return
 
-class StudentBaseDisplayFormPage(KOFADisplayFormPage):
+class StudentBaseDisplayFormPage(KofaDisplayFormPage):
     """ Page to display student base data
     """
@@ -310,5 +310,5 @@
         usertype = getattr(self.request.principal,
                            'user_type', 'system').title()
-        kofa_utils = getUtility(IKOFAUtils)
+        kofa_utils = getUtility(IKofaUtils)
         success = kofa_utils.sendContactForm(
                 self.request.principal.title,email,
@@ -323,5 +323,5 @@
         return
 
-class StudentBaseManageFormPage(KOFAEditFormPage):
+class StudentBaseManageFormPage(KofaEditFormPage):
     """ View to manage student base data
     """
@@ -388,5 +388,5 @@
         return
 
-class StudentClearanceDisplayFormPage(KOFADisplayFormPage):
+class StudentClearanceDisplayFormPage(KofaDisplayFormPage):
     """ Page to display student clearance data
     """
@@ -415,5 +415,5 @@
     @property
     def title(self):
-        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKofaUtils).PORTAL_LANGUAGE
         return translate(_('Clearance Data'), 'waeup.kofa',
             target_language=portal_language)
@@ -421,5 +421,5 @@
     @property
     def label(self):
-        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKofaUtils).PORTAL_LANGUAGE
         return translate(_('Clearance Slip of '),
             'waeup.kofa', target_language=portal_language) \
@@ -434,5 +434,5 @@
             self.context.getStudent(), studentview)
 
-class StudentClearanceManageFormPage(KOFAEditFormPage):
+class StudentClearanceManageFormPage(KofaEditFormPage):
     """ Page to edit student clearance data
     """
@@ -508,5 +508,5 @@
         return
 
-class StudentPersonalDisplayFormPage(KOFADisplayFormPage):
+class StudentPersonalDisplayFormPage(KofaDisplayFormPage):
     """ Page to display student personal data
     """
@@ -523,5 +523,5 @@
             mapping = {'a':self.context.display_fullname})
 
-class StudentPersonalManageFormPage(KOFAEditFormPage):
+class StudentPersonalManageFormPage(KofaEditFormPage):
     """ Page to edit student clearance data
     """
@@ -538,5 +538,5 @@
         return
 
-class StudyCourseDisplayFormPage(KOFADisplayFormPage):
+class StudyCourseDisplayFormPage(KofaDisplayFormPage):
     """ Page to display the student study course data
     """
@@ -556,5 +556,5 @@
     def current_mode(self):
         if self.context.certificate is not None:
-            studymodes_dict = getUtility(IKOFAUtils).getStudyModesDict()
+            studymodes_dict = getUtility(IKofaUtils).getStudyModesDict()
             return studymodes_dict[self.context.certificate.study_mode]
         return
@@ -572,5 +572,5 @@
         return
 
-class StudyCourseManageFormPage(KOFAEditFormPage):
+class StudyCourseManageFormPage(KofaEditFormPage):
     """ Page to edit the student study course data
     """
@@ -645,5 +645,5 @@
         return
 
-class StudyLevelDisplayFormPage(KOFADisplayFormPage):
+class StudyLevelDisplayFormPage(KofaDisplayFormPage):
     """ Page to display student study levels
     """
@@ -662,5 +662,5 @@
     @property
     def label(self):
-        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKofaUtils).PORTAL_LANGUAGE
         lang = self.request.cookies.get('kofa.language', portal_language)
         level_title = translate(self.context.level_title, 'waeup.kofa',
@@ -688,5 +688,5 @@
     @property
     def title(self):
-        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKofaUtils).PORTAL_LANGUAGE
         return translate(_('Level Data'), 'waeup.kofa',
             target_language=portal_language)
@@ -694,5 +694,5 @@
     @property
     def content_title(self):
-        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKofaUtils).PORTAL_LANGUAGE
         return translate(_('Course List'), 'waeup.kofa',
             target_language=portal_language)
@@ -700,5 +700,5 @@
     @property
     def label(self):
-        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKofaUtils).PORTAL_LANGUAGE
         lang = self.request.cookies.get('kofa.language', portal_language)
         level_title = translate(self.context.level_title, 'waeup.kofa',
@@ -709,5 +709,5 @@
 
     def render(self):
-        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKofaUtils).PORTAL_LANGUAGE
         Sem = translate(_('Sem.'), 'waeup.kofa', target_language=portal_language)
         Code = translate(_('Code'), 'waeup.kofa', target_language=portal_language)
@@ -735,5 +735,5 @@
             tabledata=tabledata)
 
-class StudyLevelManageFormPage(KOFAEditFormPage):
+class StudyLevelManageFormPage(KofaEditFormPage):
     """ Page to edit the student study level data
     """
@@ -762,5 +762,5 @@
     @property
     def label(self):
-        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKofaUtils).PORTAL_LANGUAGE
         lang = self.request.cookies.get('kofa.language', portal_language)
         level_title = translate(self.context.level_title, 'waeup.kofa',
@@ -853,5 +853,5 @@
         return
 
-class CourseTicketAddFormPage(KOFAAddFormPage):
+class CourseTicketAddFormPage(KofaAddFormPage):
     """Add a course ticket.
     """
@@ -890,5 +890,5 @@
         self.redirect(self.url(self.context))
 
-class CourseTicketDisplayFormPage(KOFADisplayFormPage):
+class CourseTicketDisplayFormPage(KofaDisplayFormPage):
     """ Page to display course tickets
     """
@@ -906,5 +906,5 @@
             'b':self.context.code})
 
-class CourseTicketManageFormPage(KOFAEditFormPage):
+class CourseTicketManageFormPage(KofaEditFormPage):
     """ Page to manage course tickets
     """
@@ -925,5 +925,5 @@
         return
 
-class PaymentsManageFormPage(KOFAEditFormPage):
+class PaymentsManageFormPage(KofaEditFormPage):
     """ Page to manage the student payments
 
@@ -982,5 +982,5 @@
         self.redirect(self.url(self.context, '@@addop'))
 
-class OnlinePaymentAddFormPage(KOFAAddFormPage):
+class OnlinePaymentAddFormPage(KofaAddFormPage):
     """ Page to add an online payment ticket
     """
@@ -1039,5 +1039,5 @@
         return
 
-class OnlinePaymentDisplayFormPage(KOFADisplayFormPage):
+class OnlinePaymentDisplayFormPage(KofaDisplayFormPage):
     """ Page to view an online payment ticket
     """
@@ -1138,5 +1138,5 @@
 
 
-class AccommodationManageFormPage(KOFAEditFormPage):
+class AccommodationManageFormPage(KofaEditFormPage):
     """ Page to manage bed tickets.
 
@@ -1195,5 +1195,5 @@
         return self.actions
 
-class BedTicketAddPage(KOFAPage):
+class BedTicketAddPage(KofaPage):
     """ Page to add an online payment ticket
     """
@@ -1287,5 +1287,5 @@
             'c':room_nr, 'd':bed_nr,
             'e':bed.bed_type})
-        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKofaUtils).PORTAL_LANGUAGE
         bedticket.bed_coordinates = translate(
             bc, 'waeup.kofa',target_language=portal_language)
@@ -1297,5 +1297,5 @@
         return
 
-class BedTicketDisplayFormPage(KOFADisplayFormPage):
+class BedTicketDisplayFormPage(KofaDisplayFormPage):
     """ Page to display bed tickets
     """
@@ -1325,5 +1325,5 @@
     @property
     def title(self):
-        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKofaUtils).PORTAL_LANGUAGE
         return translate(_('Bed Allocation Data'), 'waeup.kofa',
             target_language=portal_language)
@@ -1331,5 +1331,5 @@
     @property
     def label(self):
-        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKofaUtils).PORTAL_LANGUAGE
         return translate(_('Bed Allocation: '),
             'waeup.kofa', target_language=portal_language) \
@@ -1405,5 +1405,5 @@
             'c':room_nr, 'd':bed_nr,
             'e':new_bed.bed_type})
-        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKofaUtils).PORTAL_LANGUAGE
         self.context.bed_coordinates = translate(
             bc, 'waeup.kofa',target_language=portal_language)
@@ -1416,5 +1416,5 @@
         return
 
-class StudentHistoryPage(KOFAPage):
+class StudentHistoryPage(KofaPage):
     """ Page to display student clearance data
     """
@@ -1431,5 +1431,5 @@
 # Pages for students only
 
-class StudentBaseEditFormPage(KOFAEditFormPage):
+class StudentBaseEditFormPage(KofaEditFormPage):
     """ View to edit student base data
     """
@@ -1447,5 +1447,5 @@
         return
 
-class StudentChangePasswordPage(KOFAEditFormPage):
+class StudentChangePasswordPage(KofaEditFormPage):
     """ View to manage student base data
     """
@@ -1473,5 +1473,5 @@
         return
 
-class StudentFilesUploadPage(KOFAPage):
+class StudentFilesUploadPage(KofaPage):
     """ View to upload files by student
     """
@@ -1490,5 +1490,5 @@
         return
 
-class StartClearancePage(KOFAPage):
+class StartClearancePage(KofaPage):
     grok.context(IStudent)
     grok.name('start_clearance')
@@ -1593,5 +1593,5 @@
         return
 
-class RequestClearancePage(KOFAPage):
+class RequestClearancePage(KofaPage):
     grok.context(IStudent)
     grok.name('request_clearance')
@@ -1624,5 +1624,5 @@
         return
 
-class StartCourseRegistrationPage(KOFAPage):
+class StartCourseRegistrationPage(KofaPage):
     grok.context(IStudentStudyCourse)
     grok.name('start_course_registration')
@@ -1673,5 +1673,5 @@
         return
 
-class AddStudyLevelFormPage(KOFAEditFormPage):
+class AddStudyLevelFormPage(KofaEditFormPage):
     """ Page for students to add current study levels
     """
@@ -1710,5 +1710,5 @@
         return
 
-class StudyLevelEditFormPage(KOFAEditFormPage):
+class StudyLevelEditFormPage(KofaEditFormPage):
     """ Page to edit the student study level data by students
     """
@@ -1732,5 +1732,5 @@
     @property
     def label(self):
-        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKofaUtils).PORTAL_LANGUAGE
         lang = self.request.cookies.get('kofa.language', portal_language)
         level_title = translate(self.context.level_title, 'waeup.kofa',
@@ -1816,5 +1816,5 @@
         return
 
-class ChangePasswordRequestPage(KOFAForm):
+class ChangePasswordRequestPage(KofaForm):
     """Captcha'd page for students to request a password change.
     """
@@ -1851,5 +1851,5 @@
         student = list(results)[0]
         # Change password
-        kofa_utils = getUtility(IKOFAUtils)
+        kofa_utils = getUtility(IKofaUtils)
         pwd = kofa_utils.genPassword()
         IUserAccount(student).setPassword(pwd)
@@ -1866,6 +1866,6 @@
         return
 
-class SetPasswordPage(KOFAPage):
-    grok.context(IKOFAObject)
+class SetPasswordPage(KofaPage):
+    grok.context(IKofaObject)
     grok.name('setpassword')
     grok.require('waeup.Anonymous')
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/viewlets.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/viewlets.py	(revision 7811)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/viewlets.py	(revision 7819)
@@ -22,5 +22,5 @@
 from zope.i18n import translate
 from waeup.kofa.interfaces import (
-    IKOFAObject, IExtFileStore, IFileStoreNameChooser, IKOFAUtils)
+    IKofaObject, IExtFileStore, IFileStoreNameChooser, IKofaUtils)
 from waeup.kofa.interfaces import MessageFactory as _
 from waeup.kofa.utils.helpers import string_from_bytes, file_size
@@ -48,5 +48,5 @@
 from waeup.kofa.interfaces import MessageFactory as _
 
-grok.context(IKOFAObject) # Make IKOFAObject the default context
+grok.context(IKofaObject) # Make IKofaObject the default context
 grok.templatedir('browser_templates')
 
@@ -63,5 +63,5 @@
     grok.baseclass()
     grok.viewletmanager(StudentManageSidebar)
-    grok.context(IKOFAObject)
+    grok.context(IKofaObject)
     grok.view(Interface)
     grok.order(5)
@@ -73,5 +73,5 @@
     def render(self):
         url = self.view.url(self.context.getStudent(), self.link)
-        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKofaUtils).PORTAL_LANGUAGE
         lang = self.request.cookies.get('kofa.language', portal_language)
         text = translate(self.text, 'waeup.kofa',
@@ -465,5 +465,5 @@
     """
 
-    grok.context(IKOFAObject)
+    grok.context(IKofaObject)
     grok.order(4)
     grok.require('waeup.viewStudentsTab')